##  Difference between Subscription Roles and User Roles
Subscription roles are not to be confused with user roles. User roles establish the general permissions for the overall workspace, while subscription role defines the role of users for fact sheets.
Examples of user roles include Admin, Member, Viewer, and so on. On the other hand, subscription roles include roles like Application Owner, Business Owner, Project Manager, etc. For examples of commonly used subscription roles, refer to [Example Subscription Roles](https://help.sap.com/docs/leanix/ea/subscription-roles?locale=en-US&state=PRODUCTION&version=CLOUD#loio275af3a27a4410148eada5eb5d54814b__example_subscription_roles). To learn more about user roles, see [User Roles](https://help.sap.com/docs/leanix/ea/user-roles-and-permissions?locale=en-US&state=PRODUCTION&version=CLOUD "Adjust role-based permissions and define custom roles.").
